@@ -100,7 +100,7 @@ sub pattern {
     my $pat = "^$p/" . join( '.*(?<=/)', @dirs ) . '(?:/.*)?$';
     print "Line $tmp becomes: $pat\n";
     eval { $pattern = qr/$pat/ };
-    error << "EOF" if ($@);
+    error <<"EOF" if ($@);
 
 Unable to parse expression: "$tmp" (converted into "$pat")
 If it is correct, please fill a bug against pkg-js-tools.
@@ -827,6 +827,9 @@ EOT
             }
             print "Linking $dest to $src\n";
             make_symlink( $dest, $src, $tmp );
+            if ( $dest =~ m#^/usr/s?bin/# ) {
+                addsubstvar( $package, "misc:Depends", 'nodejs:any' );
+            }
         } $self->open_file("debian/nodejs/links");
     }
 
